@@ -10,7 +10,7 @@ EXAMPLE_STREAMS = ['electricity-lbmp-nyiso-west.json','electricity-load-nyiso-ny
 def random_name():
     """ Choose a random name of a stream """
     mr = MicroReader()
-    names = [n for n in mr.get_stream_names() if not '~' in n ]
+    names = [n for n in mr.get_stream_names() if '~' not in n ]
     return random.choice(names)
 
 
@@ -26,4 +26,4 @@ def get_values(name:str=None)->[float]:
 
 if __name__=='__main__':
     values = get_values()
-    print(len(values))
\ No newline at end of file
+    print(len(values))
